==> cucumber-test-combinations-maven-plugin-2.9.16-sources.jar: de/gematik/combine/tags/parser/MaxRowsTagParser.java <==
/*
 * Copyright 2023 gematik GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.combine.tags.parser;

import static de.gematik.combine.tags.parser.MaxRowsTagParser.MAX_ROWS_TAG;
import static java.lang.Integer.parseInt;
import static org.apache.commons.lang3.math.NumberUtils.isDigits;
import static org.apache.commons.lang3.math.NumberUtils.isParsable;

import de.gematik.combine.filter.table.MaxRowsFilter;
import de.gematik.combine.tags.ParsedTags;
import de.gematik.combine.tags.SingleTagParser;
import de.gematik.combine.tags.TagParser.PreParsedTag;
import javax.inject.Named;
import javax.inject.Singleton;

@Named(MAX_ROWS_TAG)
@Singleton
@SuppressWarnings("unused")
public class MaxRowsTagParser implements SingleTagParser {

  public static final String MAX_ROWS_TAG = "MaxRows";

  @Override
  public void parseTagAndRegister(PreParsedTag preParsedTag, ParsedTags parsedTags) {
    if (isDigits(preParsedTag.getValue()) && isParsable(preParsedTag.getValue())) {
      int maxRows = parseInt(preParsedTag.getValue());
      parsedTags.addConfigModifier(config -> config.toBuilder()
          .maxTableRows(maxRows)
          .build());
    } else {
      parsedTags.addTableFilter(new MaxRowsFilter(preParsedTag.getValue()).setSoft(preParsedTag.isSoft()));
    }
  }
}

==> cucumber-test-combinations-maven-plugin-2.9.21-sources.jar: de/gematik/combine/tags/parser/MaxRowsTagParser.java <==
/*
 * Copyright 2023 gematik GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.combine.tags.parser;

import static de.gematik.combine.tags.parser.MaxRowsTagParser.MAX_ROWS_TAG;
import static java.lang.Integer.parseInt;
import static org.apache.commons.lang3.math.NumberUtils.isDigits;
import static org.apache.commons.lang3.math.NumberUtils.isParsable;

import de.gematik.combine.filter.table.MaxRowsFilter;
import de.gematik.combine.tags.ParsedTags;
import de.gematik.combine.tags.SingleTagParser;
import de.gematik.combine.tags.TagParser.PreParsedTag;
import javax.inject.Named;
import javax.inject.Singleton;

@Named(MAX_ROWS_TAG)
@Singleton
@SuppressWarnings("unused")
public class MaxRowsTagParser implements SingleTagParser {

  public static final String MAX_ROWS_TAG = "MaxRows";

  @Override
  public void parseTagAndRegister(PreParsedTag preParsedTag, ParsedTags parsedTags) {
    if (isDigits(preParsedTag.getValue()) && isParsable(preParsedTag.getValue())) {
      int maxRows = parseInt(preParsedTag.getValue());
      parsedTags.addConfigModifier(config -> config.toBuilder().maxTableRows(maxRows).build());
    } else {
      parsedTags.addTableFilter(
          new MaxRowsFilter(preParsedTag.getValue()).setSoft(preParsedTag.isSoft()));
    }
  }
}
